# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkBinaryStatisticsOpeningImageFilterPython
else:
    import _itkBinaryStatisticsOpeningImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterAPython
import itk.itkImageRegionPython
import itk.itkSizePython
import itk.pyBasePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrix_fixedPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageSourcePython
import itk.itkImagePython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBAPixelPython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkBinaryStatisticsOpeningImageFilterIUC2IF2_New():
    return itkBinaryStatisticsOpeningImageFilterIUC2IF2.New()

class itkBinaryStatisticsOpeningImageFilterIUC2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC2IF2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC2IF2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC2IF2

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC2IF2 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IF2_swigregister(itkBinaryStatisticsOpeningImageFilterIUC2IF2)

def itkBinaryStatisticsOpeningImageFilterIUC2ISS2_New():
    return itkBinaryStatisticsOpeningImageFilterIUC2ISS2.New()

class itkBinaryStatisticsOpeningImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC2ISS2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC2ISS2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS2"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC2ISS2

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC2ISS2 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2ISS2_swigregister(itkBinaryStatisticsOpeningImageFilterIUC2ISS2)

def itkBinaryStatisticsOpeningImageFilterIUC2IUC2_New():
    return itkBinaryStatisticsOpeningImageFilterIUC2IUC2.New()

class itkBinaryStatisticsOpeningImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC2IUC2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC2IUC2_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC2"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC2IUC2

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC2IUC2 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC2IUC2_swigregister(itkBinaryStatisticsOpeningImageFilterIUC2IUC2)

def itkBinaryStatisticsOpeningImageFilterIUC3IF3_New():
    return itkBinaryStatisticsOpeningImageFilterIUC3IF3.New()

class itkBinaryStatisticsOpeningImageFilterIUC3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC3IF3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC3IF3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC3IF3

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC3IF3 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IF3_swigregister(itkBinaryStatisticsOpeningImageFilterIUC3IF3)

def itkBinaryStatisticsOpeningImageFilterIUC3ISS3_New():
    return itkBinaryStatisticsOpeningImageFilterIUC3ISS3.New()

class itkBinaryStatisticsOpeningImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC3ISS3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC3ISS3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS3"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC3ISS3

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC3ISS3 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3ISS3_swigregister(itkBinaryStatisticsOpeningImageFilterIUC3ISS3)

def itkBinaryStatisticsOpeningImageFilterIUC3IUC3_New():
    return itkBinaryStatisticsOpeningImageFilterIUC3IUC3.New()

class itkBinaryStatisticsOpeningImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkBinaryStatisticsOpeningImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkBinaryStatisticsOpeningImageFilterIUC3IUC3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkBinaryStatisticsOpeningImageFilterIUC3IUC3_Pointer"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_Clone(self)

    def SetFullyConnected(self, _arg):
        r"""
        SetFullyConnected(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetFullyConnected(self, _arg)

    def GetFullyConnected(self):
        r"""GetFullyConnected(self) -> bool const &"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetFullyConnected(self)

    def FullyConnectedOn(self):
        r"""FullyConnectedOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_FullyConnectedOn(self)

    def FullyConnectedOff(self):
        r"""FullyConnectedOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_FullyConnectedOff(self)
    InputEqualityComparableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetBackgroundValue(self)

    def SetForegroundValue(self, _arg):
        r"""
        SetForegroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetForegroundValue(self, _arg)

    def GetForegroundValue(self):
        r"""GetForegroundValue(self) -> unsigned char"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetForegroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC3"""
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkBinaryStatisticsOpeningImageFilterPython.delete_itkBinaryStatisticsOpeningImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkBinaryStatisticsOpeningImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkBinaryStatisticsOpeningImageFilterIUC3IUC3

        Create a new object of the class itkBinaryStatisticsOpeningImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkBinaryStatisticsOpeningImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkBinaryStatisticsOpeningImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkBinaryStatisticsOpeningImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkBinaryStatisticsOpeningImageFilterIUC3IUC3 in _itkBinaryStatisticsOpeningImageFilterPython:
_itkBinaryStatisticsOpeningImageFilterPython.itkBinaryStatisticsOpeningImageFilterIUC3IUC3_swigregister(itkBinaryStatisticsOpeningImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def binary_statistics_opening_image_filter(*args: itkt.ImageLike,  fully_connected: bool=..., background_value: int=..., foreground_value: int=..., reverse_ordering: bool=..., attribute: Union[int, str]=..., feature_image: itkt.Image=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for BinaryStatisticsOpeningImageFilter"""
    import itk

    kwarg_typehints = { 'fully_connected':fully_connected,'background_value':background_value,'foreground_value':foreground_value,'reverse_ordering':reverse_ordering,'attribute':attribute,'feature_image':feature_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.BinaryStatisticsOpeningImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def binary_statistics_opening_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.BinaryStatisticsOpeningImageFilter
    binary_statistics_opening_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    binary_statistics_opening_image_filter.__doc__ = filter_object.__doc__



